using Microsoft.EntityFrameworkCore;
using PetCompanion.Data;
using PetCompanion.Models;

namespace PetCompanion.Repositories
{
    public class PetSkillRepository
    {
        private readonly ApplicationDbContext _context;

        public PetSkillRepository(ApplicationDbContext context)
        {
            _context = context;
        }

        public async Task<IEnumerable<PetSkill>> GetPetSkills(string petId)
        {
            return await _context.PetSkills
                .Include(ps => ps.Skill)
                    .ThenInclude(s => s.Effects)
                .Where(ps => ps.PetId == petId)
                .ToListAsync();
        }

        public async Task<PetSkill> SavePetSkill(PetSkill petSkill)
        {
            if (petSkill.Id == 0)
            {
                _context.PetSkills.Add(petSkill);
            }
            else
            {
                _context.PetSkills.Update(petSkill);
            }
            await _context.SaveChangesAsync();
            return petSkill;
        }
    }
}
